QueryPipelineStatisticFlags

Struct QueryPipelineStatisticFlags 

pub struct QueryPipelineStatisticFlags(pub VkQueryPipelineStatisticFlags);
Bitmask specifying queried pipeline statistics

Tuple Fields

0: VkQueryPipelineStatisticFlags

Implementations

Source

impl QueryPipelineStatisticFlags

pub const INPUT_ASSEMBLY_VERTICES: Self

Queries managed by the pool will count the number of vertices processed by the input assembly stage

pub const INPUT_ASSEMBLY_PRIMITIVES: Self

Queries managed by the pool will count the number of primitives processed by the input assembly state

pub const VERTEX_SHADER_INVOCATIONS: Self

Queries managed by the pool will count the number of vertex shader invocations

pub const GEOMETRY_SHADER_INVOCATIONS: Self

Queries managed by the pool will count the number of geometry shader invocations

pub const GEOMETRY_SHADER_PRIMITIVES: Self

Queries managed by the pool will count the number of primitives generated by geometry shader invocations

pub const CLIPPING_INVOCATIONS: Self

Queries managed by the pool will count the number of primitives processed by the Primitive Clipping stage of the pipeline

pub const CLIPPING_PRIMITIVES: Self

Queries managed by the pool will count the number of primitives output by the Primitive Clipping stage of the pipeline

pub const FRAGMENT_SHADER_INVOCATIONS: Self

Queries managed by the pool will count the number of fragment shader invocations

pub const TESSELLATION_CONTROL_SHADER_PATCHES: Self

Queries managed by the pool will count the number of patches processed by the tessellation control shader

pub const TESSELLATION_EVALUATION_SHADER_INVOCATIONS: Self

Queries managed by the pool will count the number of invocations of the tessellation evaluation shader

pub const COMPUTE_SHADER_INVOCATIONS: Self

Queries managed by the pool will count the number of compute shader invocations

pub fn input_assembly_vertices(&self) -> Self

Queries managed by the pool will count the number of vertices processed by the input assembly stage

pub fn input_assembly_primitives(&self) -> Self

Queries managed by the pool will count the number of primitives processed by the input assembly state

pub fn vertex_shader_invocations(&self) -> Self

Queries managed by the pool will count the number of vertex shader invocations

pub fn geometry_shader_invocations(&self) -> Self

Queries managed by the pool will count the number of geometry shader invocations

pub fn geometry_shader_primitives(&self) -> Self

Queries managed by the pool will count the number of primitives generated by geometry shader invocations

pub fn clipping_invocations(&self) -> Self

Queries managed by the pool will count the number of primitives processed by the Primitive Clipping stage of the pipeline

pub fn clipping_primitives(&self) -> Self

Queries managed by the pool will count the number of primitives output by the Primitive Clipping stage of the pipeline

pub fn fragment_shader_invocations(&self) -> Self

Queries managed by the pool will count the number of fragment shader invocations

pub fn tessellation_control_shader_patches(&self) -> Self

Queries managed by the pool will count the number of patches processed by the tessellation control shader

pub fn tessellation_evaluation_shader_invocations(&self) -> Self

Queries managed by the pool will count the number of invocations of the tessellation evaluation shader

pub fn compute_shader_invocations(&self) -> Self

Queries managed by the pool will count the number of compute shader invocations